
ENTRYPOINT_ATTR = "__PACHYDERM_PIPELINE_ENTRYPOINT__"
PIPELINE_NAME_ATTR = "__PACHYDERM_PIPELINE_NAME__"
PIPELINE_INPUT_ATTR = "__PACHYDERM_PIPELINE_INPUTS__"

PIPELINE_ENV_VAR = "_PACHYDERM_PIPELINE_CONTAINER"
DEFAULT_TAG = "v0.1.0"
IMAGE = f"pachyderm/script_to_pipeline"
